@@ -1,4 +1,4 @@
-# frozen_string_literal: false
+# frozen_string_literal: true
 # = net/pop.rb
 #
 # Copyright (c) 1999-2007 Yukihiro Matsumoto.
@@ -16,7 +16,7 @@
 # NOTE: You can find Japanese version of this document at:
 # http://docs.ruby-lang.org/ja/latest/library/net=2fpop.html
 #
-#   $Id: pop.rb 56865 2016-11-21 23:05:41Z normal $
+#   $Id: pop.rb 64443 2018-08-18 08:35:42Z nagachika $
 #
 # See Net::POP3 for documentation.
 #
@@ -168,8 +168,8 @@ module Net
   #     require 'net/pop'
   #
   #     # Use APOP authentication if $isapop == true
-  #     pop = Net::POP3.APOP($is_apop).new('apop.example.com', 110)
-  #     pop.start(YourAccount', 'YourPassword') do |pop|
+  #     pop = Net::POP3.APOP($isapop).new('apop.example.com', 110)
+  #     pop.start('YourAccount', 'YourPassword') do |pop|
   #       # Rest of the code is the same.
   #     end
   #
@@ -196,7 +196,7 @@ module Net
   class POP3 < Protocol
 
     # svn revision of this library
-    Revision = %q$Revision: 56865 $.split[1]
+    Revision = %q$Revision: 64443 $.split[1]
 
     #
     # Class Parameters
@@ -467,7 +467,7 @@ module Net
 
     # Provide human-readable stringification of class state.
     def inspect
-      "#<#{self.class} #{@address}:#{@port} open=#{@started}>"
+      +"#<#{self.class} #{@address}:#{@port} open=#{@started}>"
     end
 
     # *WARNING*: This method causes a serious security hole.
@@ -550,7 +550,7 @@ module Net
         context.set_params(@ssl_params)
         s = OpenSSL::SSL::SSLSocket.new(s, context)
         s.sync_close = true
-        s.connect
+        ssl_socket_connect(s, @open_timeout)
         if context.verify_mode != OpenSSL::SSL::VERIFY_NONE
           s.post_connection_check(@address)
         end
@@ -758,7 +758,7 @@ module Net
 
     # Provide human-readable stringification of class state.
     def inspect
-      "#<#{self.class} #{@number}#{@deleted ? ' deleted' : ''}>"
+      +"#<#{self.class} #{@number}#{@deleted ? ' deleted' : ''}>"
     end
 
     #
@@ -771,7 +771,7 @@ module Net
     # === Example without block
     #
     #     POP3.start('pop.example.com', 110,
-    #                'YourAccount, 'YourPassword') do |pop|
+    #                'YourAccount', 'YourPassword') do |pop|
     #       n = 1
     #       pop.mails.each do |popmail|
     #         File.open("inbox/#{n}", 'w') do |f|
@@ -785,7 +785,7 @@ module Net
     # === Example with block
     #
     #     POP3.start('pop.example.com', 110,
-    #                'YourAccount, 'YourPassword') do |pop|
+    #                'YourAccount', 'YourPassword') do |pop|
     #       n = 1
     #       pop.mails.each do |popmail|
     #         File.open("inbox/#{n}", 'w') do |f|
@@ -799,7 +799,7 @@ module Net
     #
     # This method raises a POPError if an error occurs.
     #
-    def pop( dest = '', &block ) # :yield: message_chunk
+    def pop( dest = +'', &block ) # :yield: message_chunk
       if block_given?
         @command.retr(@number, &block)
         nil
@@ -819,7 +819,7 @@ module Net
     # The optional +dest+ argument is obsolete.
     #
     # This method raises a POPError if an error occurs.
-    def top(lines, dest = '')
+    def top(lines, dest = +'')
       @command.top(@number, lines) do |chunk|
         dest << chunk
       end
@@ -831,7 +831,7 @@ module Net
     # The optional +dest+ argument is obsolete.
     #
     # This method raises a POPError if an error occurs.
-    def header(dest = '')
+    def header(dest = +'')
       top(0, dest)
     end
 
@@ -844,7 +844,7 @@ module Net
     # === Example
     #
     #     POP3.start('pop.example.com', 110,
-    #                'YourAccount, 'YourPassword') do |pop|
+    #                'YourAccount', 'YourPassword') do |pop|
     #       n = 1
     #       pop.mails.each do |popmail|
     #         File.open("inbox/#{n}", 'w') do |f|
@@ -898,7 +898,7 @@ module Net
     attr_reader :socket
 
     def inspect
-      "#<#{self.class} socket=#{@socket}>"
+      +"#<#{self.class} socket=#{@socket}>"
     end
 
     def auth(account, password)
